## Code Contributors

The following people contributed to the ProbNum repository.

**Maintainers:**

- [Jonathan Wenger](https://github.com/jonathanwenger)
- [Nicholas Krämer](https://github.com/pnkraemer)
- [Nathanael Bosch](https://github.com/nathanaelbosch)

**Other:** [Maren Mahsereci](https://github.com/mmahsereci), [Marvin Pförtner](https://github.com/marvinpfoertner), [Thomas Gläßle](https://github.com/coldfix)

If you feel like you have made substantial contributions to ProbNum, contact the maintainers of the package. Your name 
will then be added here.
